===============================
Federated Monsters
===============================

.. image:: https://badge.fury.io/py/federated_monsters.svg
    :target: http://badge.fury.io/py/federated_monsters
    
.. image:: https://travis-ci.org/colatkinson/federated_monsters.svg?branch=master
        :target: https://travis-ci.org/colatkinson/federated_monsters

.. image:: https://pypip.in/d/federated_monsters/badge.svg
        :target: https://pypi.python.org/pypi/federated_monsters


Federated Monsters is a game that seeks to follow the format of games like Pokemon, but to instead use a federated server format to store and trade creatures

* Free software: GPLv3 license
* Documentation: http://federated_monsters.readthedocs.org.

Features
--------

* TODO